==> aws-java-sdk-logs-1.11.46-sources.jar: com/amazonaws/services/logs/model/transform/PutDestinationPolicyRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.logs.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * PutDestinationPolicyRequest Marshaller
 */
public class PutDestinationPolicyRequestMarshaller implements Marshaller<Request<PutDestinationPolicyRequest>, PutDestinationPolicyRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public PutDestinationPolicyRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<PutDestinationPolicyRequest> marshall(PutDestinationPolicyRequest putDestinationPolicyRequest) {

        if (putDestinationPolicyRequest == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(...)");
        }

        Request<PutDestinationPolicyRequest> request = new DefaultRequest<PutDestinationPolicyRequest>(putDestinationPolicyRequest, "AWSLogs");
        request.addHeader("X-Amz-Target", "Logs_20140328.PutDestinationPolicy");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (putDestinationPolicyRequest.getDestinationName() != null) {
                jsonGenerator.writeFieldName("destinationName").writeValue(putDestinationPolicyRequest.getDestinationName());
            }
            if (putDestinationPolicyRequest.getAccessPolicy() != null) {
                jsonGenerator.writeFieldName("accessPolicy").writeValue(putDestinationPolicyRequest.getAccessPolicy());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-logs-1.11.48-sources.jar: com/amazonaws/services/logs/model/transform/PutDestinationPolicyRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.logs.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * PutDestinationPolicyRequest Marshaller
 */
public class PutDestinationPolicyRequestMarshaller implements Marshaller<Request<PutDestinationPolicyRequest>, PutDestinationPolicyRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public PutDestinationPolicyRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<PutDestinationPolicyRequest> marshall(PutDestinationPolicyRequest putDestinationPolicyRequest) {

        if (putDestinationPolicyRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<PutDestinationPolicyRequest> request = new DefaultRequest<PutDestinationPolicyRequest>(putDestinationPolicyRequest, "AWSLogs");
        request.addHeader("X-Amz-Target", "Logs_20140328.PutDestinationPolicy");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (putDestinationPolicyRequest.getDestinationName() != null) {
                jsonGenerator.writeFieldName("destinationName").writeValue(putDestinationPolicyRequest.getDestinationName());
            }
            if (putDestinationPolicyRequest.getAccessPolicy() != null) {
                jsonGenerator.writeFieldName("accessPolicy").writeValue(putDestinationPolicyRequest.getAccessPolicy());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
